@@ -17,15 +17,6 @@
 PATTERN="\"config\":{"
 KEY="\"config_key\":\""
 
-function prepare()
-{
-	cp $SRC_IMG $TGT_IMG
-	test -d $TMPDIR || mkdir $TMPDIR
-	read_luks2_json0 $TGT_IMG $TMPDIR/json0
-	read_luks2_bin_hdr0 $TGT_IMG $TMPDIR/hdr0
-	read_luks2_bin_hdr1 $TGT_IMG $TMPDIR/hdr1
-}
-
 function generate()
 {
 	read -r json_str < $TMPDIR/json0
@@ -50,40 +41,20 @@ function generate()
 
 	printf $format_str $KEY $fill ${json_str:$offset} | _dd of=$TMPDIR/json0 bs=1 seek=$offset conv=notrunc
 
-	merge_bin_hdr_with_json $TMPDIR/hdr0 $TMPDIR/json0 $TMPDIR/area0
-	erase_checksum $TMPDIR/area0
-	chks0=$(calc_sha256_checksum_file $TMPDIR/area0)
-	write_checksum $chks0 $TMPDIR/area0
-	write_luks2_hdr0 $TMPDIR/area0 $TGT_IMG
-	kill_bin_hdr $TMPDIR/hdr1
-	write_luks2_hdr1 $TMPDIR/hdr1 $TGT_IMG
+	lib_mangle_json_hdr0_kill_hdr1
 }
 
 function check()
 {
-	read_luks2_bin_hdr1 $TGT_IMG $TMPDIR/hdr_res1
-	local str_res1=$(head -c 6 $TMPDIR/hdr_res1)
-	test "$str_res1" = "VACUUM" || exit 2
+	lib_hdr1_killed || exit 2
+	lib_hdr0_checksum || exit 2
 
 	read_luks2_json0 $TGT_IMG $TMPDIR/json_res0
-	chks_res0=$(read_sha256_checksum $TGT_IMG)
-	test "$chks0" = "$chks_res0" || exit 2
 	read -r json_str_res0 < $TMPDIR/json_res0
 	test ${#json_str_res0} -eq $((LUKS2_JSON_SIZE*512)) || exit 2
 }
 
-function cleanup()
-{
-	rm -f $TMPDIR/*
-	rm -fd $TMPDIR
-}
-
-test $# -eq 2 || exit 1
-
-TGT_IMG=$1/$(test_img_name $0)
-SRC_IMG=$2
-
-prepare
+lib_prepare $@
 generate
 check
-cleanup
+lib_cleanup
